﻿#region License
// Copyright 2008 Lars Wilhelmsen.

// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at

//    http://www.apache.org/licenses/LICENSE-2.0
//    or the supplied LICENSE-2.0.txt included in the Visual Studio solution.

// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#endregion
namespace TestApplication
{
    using System;
    using System.Security;
    using System.Security.Principal;
    using System.Security.Permissions;

    class Program
    {
        static void Main()
        {
            System.Threading.Thread.CurrentPrincipal = new WindowsPrincipal(WindowsIdentity.GetCurrent());

           // Example of imperative permission demand:
           //var permission = new LarsW.Security.PrincipalPermissionExAttribute(SecurityAction.Demand,
           //                                                                   "configurableEliteGroup").CreatePermission();
           //permission.Demand();

            var program = new Program();
            Console.WriteLine("Trying to call methods with limited permissions...");
            try
            {
                program.NeedsToBeAuthenticated();
            }
            catch(SecurityException ex)
            {
                Console.WriteLine(ex.ToString());
                Console.WriteLine("You did not have the permissions to call program.NeedsToBeAuthenticated()");
            }
            try
            {
                program.OnlyMembersOfTheEliteConfigurableGroupCanCallThisOne();
            }
            catch(SecurityException ex)
            {
                Console.WriteLine(ex.ToString());
                Console.WriteLine("You did not have the permissions to call program.OnlyMembersOfTheEliteConfigurableGroupCanCallThisOne()");
            }
            try
            {
                program.ExclusiveForAdministrators();
            }
            catch(SecurityException ex)
            {
                Console.WriteLine(ex.ToString());
                Console.WriteLine("You did not have the permissions to call program.ExclusiveForAdministrators()");
            }
            Console.WriteLine("Test done!");
        }

        [Permissions.AuthenticatedPermission(SecurityAction.Demand)]
        private void NeedsToBeAuthenticated()
        {
            Console.WriteLine("Called NeedsToBeAuthenticated() successfully.");
        }

        [Permissions.ConfigurableEliteGroupPermission(SecurityAction.Demand)]
        private void OnlyMembersOfTheEliteConfigurableGroupCanCallThisOne()
        {
            Console.WriteLine("Called OnlyMembersOfTheEliteConfigurableGroupCanCallThisOne() successfully.");
        }

        [Permissions.AdministratorsPermission(SecurityAction.Demand)]
        private void ExclusiveForAdministrators()
        {
            Console.WriteLine("Called ExclusiveForAdministrators() successfully.");
        }
    }
}
